Method: SQLite3::Database#rollback
- Defined in:
- lib/sqlite3/database.rb
#rollback ⇒ Object
Rolls the current transaction back. If there is no current transaction, this will cause an error to be raised. This returns true, in order to allow it to be used in idioms like abort? and rollback or commit.
596 597 598 599 600 |
# File 'lib/sqlite3/database.rb', line 596 def rollback execute "rollback transaction" @transaction_active = false true end |